# Picked Protein Group FDR

[![PyPI version](https://img.shields.io/pypi/v/picked_group_fdr.svg?logo=pypi&logoColor=FFE873)](https://pypi.org/project/picked_group_fdr/)
[![Supported Python versions](https://img.shields.io/pypi/pyversions/picked_group_fdr.svg?logo=python&logoColor=FFE873)](https://pypi.org/project/picked_group_fdr/)
[![PyPI downloads](https://img.shields.io/pypi/dm/picked_group_fdr.svg)](https://pypistats.org/packages/picked_group_fdr)

Scalable, accurate and sensitive protein group FDRs for large-scale mass spectrometry experiments.

Different search engine outputs are supported:
- [MaxQuant](https://www.maxquant.org/) (LFQ, TMT, SILAC)
- [Percolator](https://github.com/percolator/percolator) (no quantification)
- [FragPipe](https://fragpipe.nesvilab.org/) (LFQ)
- [Sage](https://github.com/lazear/sage) (LFQ)
- [DIA-NN](https://github.com/vdemichev/DiaNN/) (LFQ)
- [Mokapot](https://github.com/wfondrie/mokapot) (no quantification)
- [Oktoberfest](https://github.com/wilhelm-lab/oktoberfest) (no quantification)
- [MS2Rescore](https://github.com/compomics/ms2rescore) (no quantification)


## Documentation

The official Picked Group FDR documentation can be found at https://picked-group-fdr.readthedocs.io.

The documentation includes installation instructions, basic usage principles, examples and the API documentation.

Additionally, examples on how to run Picked Protein Group FDR with  different search engine outputs can be found in the `data/` folder.


## How to cite

Please cite the main publication:

The, M., Samaras, P., Kuster, B., & Wilhelm, M. (2022). *Reanalysis of ProteomicsDB Using an Accurate, Sensitive, and Scalable False Discovery Rate Estimation Approach for Protein Groups.* Molecular & Cellular Proteomics, 21(12).

